@@ -6,7 +6,7 @@
 # all distribution works, otherwise you have to use the statically link program.
 # I am lazy... do not want to compile it everytime.
 # Note: from syslinux 3.30-pre5, we add vesamenu.c32 here.
-DRBL_NEED="isolinux.bin memdisk menu.c32 vesamenu.c32 pxelinux.0 gpxelinux.0 chain.c32 mboot.c32 sanboot.c32 README.menu mbr.bin syslinux.exe"
+DRBL_NEED="isolinux.bin memdisk menu.c32 vesamenu.c32 pxelinux.0 gpxelinux.0 chain.c32 mboot.c32 sanboot.c32 README.menu mbr.bin"
 SYSLINUX_URL="http://www.kernel.org/pub/linux/utils/boot/syslinux/"
 
 usage() {
